==========
Change Log
==========

0.0.3
-----

Changes:
~~~~~~~~

- Added ability to Search through playlists
- Updated Documentation
- Introduced some initial testing


0.0.2
-----

Changes:
~~~~~~~~

- Fixed upload to PyPi.


0.0.1
-----

Changes:
~~~~~~~~

- Initial version.
